#delimit;
clear;
set mem 1000m;
set more off;
capture log close;
log using log\episodes, replace;

/*
1. re-assign grid date
2. make new variables, recode
3. make dummies
*/

scalar newgrid = date("Apr 1 1993","MDY");

matrix oldGrid = (18, 12, 8, 6, 4 \
				 21, 14, 9, 8, 6 \
				 24, 15, 12, 9, 8 \
				 27, 18, 15, 12, 10 \
				 52, 40, 30, 25, 20 \
				 78, 60, 54, 48, 36 \
				 102, 90, 78, 72, 60);
				 
matrix newGrid = (22, 16, 10  \
				 24, 18, 12 \
				 26, 20, 14 \
				 28, 22, 16 \
				 52, 40, 34 \
				 78, 62, 52 \
				 102, 84, 72);
				 
matrix changeGrid = (4, 10, 8, 10, 12, 6 \
				 3, 10, 9, 10, 12, 6 \
				 2, 11, 8, 11, 12, 6 \
				 1, 10, 7, 10, 12, 6 \
				 0, 12, 10, 15, 20, 14 \
				 0, 18, 8, 14, 26, 16 \
				 0, 12, 6, 12, 24, 12);

use episodes, clear;

***1. define sample;
*look at observations considered for parole within a year of reform;
gen byte gridPeriod = (dtrated >= date("Apr 1, 1992", "MDY") & 
dtrated < date("Apr 1, 1994", "MDY"));
tab gridPeriod;
gen byte gridPeriodLarge = (dtrated >= date("Apr 1, 1989", "MDY") & 
dtrated < date("Apr 1, 1997", "MDY"));
tab gridPeriodLarge;

*drop later appearances if there are multiple;
duplicates report uno if gridPeriod;
egen int firstDtrated = min(dtrated) if gridPeriod, by(uno);
gen byte obsIsFirstDtrated = (firstDtrated == dtrated);
tab obsIsFirstDtrated if gridPeriod;
*check that sequence is admit date, date rated, release date, future
admit;
gen byte validDates = (admitdate <= dtrated & dtrated <= actualreldate & 
actualreldate <= futureadmdate);
tab validDates if gridPeriod & obsIsFirstDtrated;
*check that time served is 3 months to 10 years;
gen byte timeLowerBound = (servedaysprsnj >= 90);
gen byte timeUpperBound = (servedaysprsnj <= 10*365);
tab timeLowerBound timeUpperBound if gridPeriod & validDates & obsIsFirstDtrated;

gen byte baseObserv = (gridPeriod & validDates & timeLowerBound & 
timeUpperBound & obsIsFirstDtrated);
tab baseObserv;

gen byte baseObservLarge = (gridPeriodLarge & validDates & timeLowerBound & 
timeUpperBound);
tab baseObservLarge;

*copy release date for base observation over to others. need to make sure 
later that obs within horizon are only those after the base episode and not
those before;
egen int baseRelDate = max(actualreldate*baseObserv), by(uno);
egen int baseAdmitDate = max(admitdate*baseObserv), by(uno);

***2. make new variables, recode;
*date-related;
gen int month = mofd(dtrated);
gen int quarter = qofd(dtrated);
gen int year = year(dtrated);
gen byte after = (dtrated >= date("April 1, 1993", "MDY"));
sum quarter;
*quarter 117 refers to 1989:Q2;
gen byte period = floor((quarter-117)/4);
tab period;

*sucgroup related;
recode sucscore (13/20 = 5) (11/12 = 4) (9/10 = 3) (6/8 = 2) 
(0/5 = 1), gen(sucgroupBef);
recode sucscore (14/20 = 6) (13 = 5) (11/12 = 4) (9/10 = 3) (6/8 = 2) 
(0/5 = 1), gen(sucgroup);
recode sucscore (14/20 = 3) (9/13 = 2) (0/8 = 1), gen(sucgroupAft);

*sentence-related;
gen float grid = parmonths/12;
gen float timeserv = servedaysprsnj/365;
gen float sentlen = sentlengthdays/365;
gen int cell = severitylevel*22 + sucscore;
gen byte boardagree = (boarddecision == "A");
gen byte boardup = (boarddecision == "+");
gen int yearrel = year(actualreldate);
gen int yearadmit = year(admitdate);
gen byte maxout = (departure == 3 | departure == 4);

*demographic-related;
gen int ageatfirstcontactNum = round((firstcontactdate - birthdate)/365);
replace ageatfirstcontactNum = 16 if ageatfirstcontactNum < 16;
gen byte ageAtEntry = round(ageatrelease-timeserv);
replace ageAtEntry = 18 if ageAtEntry < 18;
gen int ageAtEntry2= ageAtEntry^2;
gen byte white = (racecode == 1);
gen byte black = (racecode == 2);
gen byte female = (sexcode == "F");
gen byte employ = (employmentstatus == 1);

*education recodes
scores 17-21 indicate advanced training after bachelor's,
30 is some technical school (so 10 years edu), 31 is completed (so 12)
90 is no education
0, 97, 98 are not reported
99 is a code not discussed in the codebook;
sum education;
local meanedu = r(mean);
recode education (17/21 = 16) (0 97/99= `meanedu') (90 = 0) (30 = 10) (31 = 12);
*divide test scores into 5 quartiles;
xtile read = wratread, n(5);
xtile math = wratmath, n(5);
xtile spel = wratspel, n(5);

*topcode;
replace priorincar = 5 if priorincar > 5;
replace priorconv = 10 if priorconv > 10;
replace cumdisciptotal = 5 if cumdisciptotal > 5;
replace sentlen = 60 if sentlen > 60;

*reconvictions;
gen byte reconv = (reconvchkpts >= 1 & reconvchkpts <= 6);

*calculate recid stats;
gen int reciddist = futureadmdate-actualreldate;
gen byte recid = (reciddist <= 365*3);

#delimit;
foreach t of numlist 0 1 2 3 10 {;
	gen byte recid`t' = (reciddist <= 365*`t');
	gen byte recid`t'Start = (reciddist < 365+365*`t');
	replace recid`t'Start = recid`t' if after;
};
d;

*recode revocations;
egen int newConvictionDate = min(admitdate), by(uno sentdate curroff1);
gen byte newConviction = (admitdate == newConvictionDate);

*recode parole revocations without new convictions by felony, misdemeanor
	or technical;
tab parrevreason;
gen byte felony = (parrevreason == 7 | parrevreason == 9 | parrevreason == 11)
	if !newConviction;
replace curroff1 = -1 if felony == 1;
gen byte misdemeanor = (parrevreason == 6 | parrevreason == 8 | parrevreason == 10)
	if !newConviction;
replace curroff1 = -2 if misdemeanor == 1;
gen byte technical = (!felony & !misdemeanor & !newConviction);
replace curroff1 = -3 if technical == 1;
gen byte revoc = (curroff1 < 0);

*define the cell level for clustering;
gen cellCluster = (sucgroup-1)*7+severitylevel;
gen cellCluster2 = (sucscore)*7+severitylevel;

***3. Construct time change variables;
preserve;
#delimit;
tempfile timeChange;
keep if baseObserv;
collapse (mean) timeserv, by (cell after);
reshape wide timeserv, i(cell) j(after);
gen timechange=timeserv1-timeserv0;
drop timeserv*;
sort cell;
save `timeChange';
restore;

sort cell;
merge cell using `timeChange', uniqusing;
tab _merge;
drop _merge;

***4. make dummies;
#delimit;
foreach var of varlist marital curroff1 severitylevel priori priorc 
race sexc employmentstatus major ageAtEntry departure yearrel yearadmit 
boardd cell cumdisciptotal drugbehavprob alcbehavprob  
read math spel
mentalhealthhigh ageatfirstcontactNum
successfactorfactoraage 
successfactorbprio
successfactord 
successfactoreheroinor 
successfactorfcommitment 
successfactorgfullyempl 
successfactorhhadwrat { ;
	tab `var' if baseObservLarge, gen(`var'd) missing;
	drop `var'd1;
};

label var grid "Parole Grid Rec (Years)";
label var timeserv "Time Served (Years)";
label var sentlen "Sentence Length (Years)";
label var recid "Recidivate?";
label var after "Rated After April 1, 1993";

compress;

save episodes_clean.dta, replace;

capture log close;
