#delimit;
capture log close;
log using log\figures, replace;

clear all;

set mem 800m;
set matsize 800;
set more off;



*****************
*FIGURE 1*
*****************;
#delimit;
use sample_analysis.dta, clear;
replace grid = grid*12;
replace timeserv = timeserv*12;

collapse grid timeserv if !after, by(sucgroupBef severitylevel);

forvalues x = 1/5 {;
	gen t`x' = timeserv if sucgroupBef == `x';
	gen g`x' =  grid if sucgroupBef == `x';
	local graph`x'   scatter t`x' g`x', mlabel(severitylevel) mlabsize(small);
};

label define severitylevel 1 "I";
label define severitylevel 2 "II", add;
label define severitylevel 3 "III", add;
label define severitylevel 4 "IV", add;
label define severitylevel 5 "V", add;
label define severitylevel 6 "VI", add;
label define severitylevel 7 "VII", add;
label values severitylevel severitylevel;


`graph1' msymbol(o)  mlabcolor("128 0 0") mcolor("128 0 0") 
|| `graph2' msymbol(d) mlabcolor("96 0 32") mcolor("96 0 32") 
|| `graph3' msymbol(t) mlabcolor("64 0 64") mcolor("64 0 64") 
|| `graph4' msymbol(s) mlabcolor("32 0 96") mcolor("32 0 96") 
|| `graph5' msymbol(x) mlabcolor("0 0 128") mcolor("0 0 128") 
ytitle("Actual Time Served (Months)")
xtitle("Parole Guidelines (Months)")
title("Figure 1 - Effect of Guidelines on Time Served") 
    legend(order(- "Criminal History:" 5 "Excellent" 4 "Good" 3 "Average" 2 "Fair" 1 "Poor") 
     cols(1) region(fcolor(gs15) lstyle(none)) pos(10) ring(0))
     graphregion(fcolor(white))
      xlabel(0(50)100) yscale(range(0 100)) ylabel(0(50)100);
graph export "Figures/fig1.pdf", replace;



*****************
*FIGURE 2*
*****************;
#delimit;
use sample_large if period >= 1 & period <= 6, clear;
replace timeserv = timeserv*12;
replace grid = grid*12;
collapse parolerecavg=grid timeservavg=timeserv recidmeanavg=recid, by(quarter);

label var timeservavg "Time Served";
label var parolerecavg " ";

tsset quarter;
format quarter %tqMon_yy;
label var quarter "Date Offender Considered for Parole";

*FIGURE 2A*;
scatter timeservavg quarter if quarter <=132, msymbol(S) mcolor(dknavy) lcolor(dknavy) c(l) || 
scatter timeservavg quarter if quarter > 132, msymbol(S) mcolor(dknavy) lcolor(dknavy) c(l) || 
scatter parolerecavg quarter if quarter <=132, yaxis(2) mcolor(emidblue) lcolor(emidblue) c(l) lpattern("-") ||
scatter parolerecavg quarter if quarter >132, yaxis(2) mcolor(emidblue) lcolor(emidblue) c(l) lpattern("-") 
tlabel(1990q2(4)1995q4, angle(45)) 
xline(132.5)
ytitle("Months") 
legend(order(1 3 "Guidelines") pos(10) ring(0) col(1) region(fcolor(gs15) lstyle(none)))
xscale(titlegap(5))
yscale(range(20 35) axis(1))
ylabel(20(5)35, axis(1))
yscale(range(20 35) axis(2))
ylabel(none, axis(2))
ytitle(" " " " " ", axis(2)) xtitle(" ")
 graphregion(fcolor(white)) saving(Figures/t/fig2a, replace) nodraw; 

*FIGURE 2B*;
label var timeservavg "Time Served (Months)";
label var recidmeanavg "Share Recidivating";
scatter timeservavg quarter if quarter <=132, ylabel(20(5)35) mcolor(dknavy) lcolor(dknavy) msymbol(S) c(l) ||
scatter timeservavg quarter if quarter >132,  ylabel(20(5)35) mcolor(dknavy) lcolor(dknavy) msymbol(S) c(l) || 
scatter recidmeanavg quarter if quarter <=132, mcolor(emidblue) lcolor(emidblue) msymbol(T) c(l) lpattern("_") yaxis(2) yscale(r(0.3 0.47) axis(2)) ||
scatter recidmeanavg quarter if quarter >132, mcolor(emidblue) lcolor(emidblue) msymbol(T) c(l) lpattern("_") yaxis(2)
xline(132.5)
tlabel(1990q2(4)1995q4, angle(45)) 

legend(pos(10) ring(0) col(1) region(fcolor(gs15) lstyle(none))
order(1 "Time Served" 3 "Recidivism"))
xscale(titlegap(5))
 graphregion(fcolor(white)) saving(Figures/t/fig2b, replace)  nodraw; 

gr combine Figures/t/fig2a.gph Figures/t/fig2b.gph, 
title("Figure 2 - Effects of Guidelines Change - Timeseries", size(medium))
 cols(1) iscale(.6) graphregion(fcolor(white)) xsize(8.5) ysize(10);
 graph export "Figures/fig2.pdf", replace;




*****************
*FIGURE 3*
*****************;

*construct sev level-success group means;
#delimit;
use sample_analysis.dta, clear;
replace grid = grid*12;
replace timeserv = timeserv*12;

collapse grid timeserv recid (count) groupcount=grid if severitylevel <=5, by(severitylevel sucgroup after);

sort severitylevel sucgroup after;
by severitylevel sucgroup: gen parchange = grid - grid[_n-1];
by severitylevel sucgroup: gen timechange = timeserv - timeserv[_n-1];
by severitylevel sucgroup: gen recidChange = recid - recid[_n-1];
by severitylevel sucgroup: gen groupCountDouble = groupcount + groupcount[_n-1];
*drop obs which don't have change (these were "before" obs);
drop if parchange == .;


forvalues x = 1/6 {;
gen tc`x' = timechange if sucgroup == `x';
gen pc`x' =  parchange if sucgroup == `x';
gen rc`x' =  recidChange if sucgroup == `x';
local graph`x'  || scatter tc`x' pc`x' [fweight=groupCountDouble], mlabel(severitylevel) ;
local graphR`x'  || scatter rc`x' tc`x' [fweight=groupCountDouble], mlabel(severitylevel);
};

regress timechange parchange [aw=groupCountDouble];
predict fit;


regress recidChange timechange [aw=groupCountDouble];
predict fitRecid;

label define severitylevel 1 "I";
label define severitylevel 2 "II", add;
label define severitylevel 3 "III", add;
label define severitylevel 4 "IV", add;
label define severitylevel 5 "V", add;
label define severitylevel 6 "VI", add;
label define severitylevel 7 "VII", add;
label values severitylevel severitylevel;

sort parchange;

*FIGURE 3A*;
scatter tc1 pc1 [fweight=groupCountDouble], 
mlabsize(small) mlabel(severitylevel)  msymbol(o) mcolor("128 0 64") mlabcolor("128 0 64") 
ytitle("Change in Time Served (Months)") 
xtitle("Change in Guidelines (Months)") 

  `graph2' msymbol(d)  mcolor("128 0 0") mlabcolor("128 0 0")
 `graph3' msymbol(t) mcolor("96 0 32") mlabcolor("96 0 32") 
 `graph4' msymbol(s) mcolor("64 0 64") mlabcolor("64 0 64")
 `graph5' msymbol(x) mcolor("32 0 96") mlabcolor("32 0 96")
  `graph6' msymbol(oh)  mlabcolor("0 0 128") mcolor("0 0 128")
   graphregion(fcolor(white)) legend(off)
    xlabel(0(5)20) yscale(range(0 15)) ylabel(0(5)15)   
 || line fit parchange if parchange > 0 & parchange < 20, saving(Figures/t/fig3a, replace)  nodraw;


*FIGURE 3B*;
sort timechange;

scatter rc1 tc1, 
mlabsize(small) mlabel(severitylevel)  msymbol(o) mcolor("128 0 64") mlabcolor("128 0 64") 
xtitle("Change in Time Served (Months)") 
ytitle("Change in Recidivism") 

  `graphR2' msymbol(d)  mcolor("128 0 0") mlabcolor("128 0 0")
 `graphR3' msymbol(t) mcolor("96 0 32") mlabcolor("96 0 32") 
 `graphR4' msymbol(s) mcolor("64 0 64") mlabcolor("64 0 64")
 `graphR5' msymbol(x) mcolor("32 0 96") mlabcolor("32 0 96")
  `graphR6' msymbol(oh)  mlabcolor("0 0 128") mcolor("0 0 128")
  || line fitRecid timechange if timechange > 0 & timechange < 15,
   graphregion(fcolor(white)) saving(Figures/t/fig3b, replace)  nodraw
   xscale(range(0 12)) xlabel(0(4)12) ylabel(#3)
   legend(order(1 "Poor (0-5)" 2 "Fair/Poor (6-8)" 3 "Average (9-10)" 4 "Good/Avg (11-12)" 5 "Excellent/Avg (13)"  6 "Excellent (14-20)") 
  region(fcolor(gs15) lstyle(none)) pos(6) size(small) cols(3)) ;

gr combine Figures/t/fig3a.gph Figures/t/fig3b.gph, 
title("Figure 3 - Effects of Guidelines Change - Cell-Level", size(medium)) 
iscale(.7) graphregion(fcolor(white)) cols(1) xsize(8.5) ysize(10);
 graph export "Figures/fig3.pdf", replace; 



*****************
*FIGURE 4*
*****************;
use figures/fig4data, clear;
local style "lcolor(dknavy) lwidth(vthick)";

*FIGURE 4A*;
line level time if group == 9, `style' || 
line level time if group == 10, `style'  lpattern("-")|| 
line level time if group == 11, `style' 
legend(off)
ylabel(2 "A" 1 "B", angle(0))
xscale(range(0 3))
xlabel(0 1 2 3)
ytitle(" ")
yscale(range(0 3))
xtitle("Years Since Admission")
subtitle("Incapacitation Measure in Past Work - Shavell (1987)", size(medium))
graphregion(fcolor(white))
saving(Figures/t/fig4a, replace) nodraw;

*FIGURE 4B*;
line level time if group == 1, `style' || 
line level time if group == 2, `style'  lpattern("-")|| 
line level time if group == 3, `style'  || 
line level time if group == 4, `style' lpattern("-")
legend(off)
ylabel(2 "A" 1 "B", angle(0))
ytitle(" ")
yscale(range(0 3))
xtitle("Years Since Admission")
subtitle("Measure From Release Date - Captures Aging and Rehab Effects", size(medium))
graphregion(fcolor(white))
saving(Figures/t/fig4b, replace) nodraw;


*FIGURE 4C*;
twoway line level time if group == 5, `style' || 
line level time if group == 6, `style'  lpattern("-")|| 
line level time if group == 7, `style'  || 
line level time if group == 8, `style' lpattern("-") ||
line level time if group == 12, lcolor(emidblue)  lwidth(thick) lpattern("_")
legend(off)
ylabel(2 "A" 1 "B", angle(0))
ytitle(" ")
yscale(range(0 3))
xtitle("Years Since Admission")
subtitle("Measure From Admission Date - Captures Rehab and Incap Effects", size(medium))
graphregion(fcolor(white))
saving(Figures/t/fig4c, replace) nodraw;


gr combine Figures/t/fig4a.gph Figures/t/fig4b.gph Figures/t/fig4c.gph , 
title("Figure 4 - Framework for Comparing" "Rehabilitation, Incapacitation and Aging", size(medium)) 
iscale(0.6) cols(1) graphregion(fcolor(white)) xsize(8.5) ysize(9);
  graph export "Figures/fig4.pdf", replace;
 

twoway line level time if group == 5, `style' || 
line level time if group == 6, `style'  lpattern("-")|| 
line level time if group == 7, `style'  || 
line level time if group == 8, `style' lpattern("-") ||
line level time if group == 12, lcolor(emidblue)  lwidth(thick) lpattern("_")
legend(order(1 "In Prison" 2 "Observation Period" 5 "Adm - Release") ring(2) pos(6) rows(1) size(small))
ylabel(2 "A" 1 "B", angle(0))
ytitle(" ")
yscale(range(0 3))
xtitle("Years Since Admission")
subtitle("Measure From Admission Date - Captures Rehab and Incap Effects", size(medium))
graphregion(fcolor(white))
saving(Figures/t/fig4legend, replace);
gr export Figures/fig4legend.pdf, replace;



*****************
*FIGURE 5*
*****************;
use sample_analysis, clear;
keep reciddist after timeserv;
replace reciddist = 100000 if reciddist == .;

count if after;
local afterN = r(N);
count if !after;
local beforeN = r(N);

tempfile reldate admitdate;

preserve;
gen recidq = ceil(reciddist/365*4)/4;
sort recidq;
cumul recidq if !after, gen(cumrbefRel);
cumul recidq if after, gen(cumraftRel);
egen cumrbefRelMax = max(cumrbefRel), by(recidq);
egen cumraftRelMax = max(cumraftRel), by(recidq);
gen diffRel = cumrbefRelMax-cumraftRelMax;
egen shareRecidBef = sum((!after)/`beforeN'), by(recidq);
egen shareRecidAft = sum((after)/`afterN'), by(recidq);
duplicates drop recidq, force;
keep if recidq <= 15;
sort recidq;
keep recidq diffRel shareRecidBef shareRecidAft;
save `reldate';
restore;

*measure from start date rather than release date for incap;
replace reciddist = reciddist + timeserv*365;
gen recidq = ceil((reciddist/365+timeserv)*4)/4;
sort recidq;
cumul recidq if !after, gen(cumrbefAdm);
cumul recidq if after, gen(cumraftAdm);
egen cumrbefAdmMax = max(cumrbefAdm), by(recidq);
egen cumraftAdmMax = max(cumraftAdm), by(recidq);
egen shareRecidBefAdm = sum((!after)/`beforeN'), by(recidq);
egen shareRecidAftAdm = sum((after)/`afterN'), by(recidq);
duplicates drop recidq, force;
gen diffAdm = cumrbefAdmMax-cumraftAdmMax;
keep if recidq <= 15;
sort recidq;
merge recidq using `reldate', unique;
tab _merge;

sort recidq;

label var shareRecidBef "FY93 Grid Cohort";
label var shareRecidAft "FY94 Grid Cohort";
label var diffRel "Difference";


*FIGURE 5A*;
scatter shareRecidBef recidq, mcolor(dknavy) || 
scatter shareRecidAft recidq , mcolor(emidblue) msymbol(Oh) ||
line diffRel recidq, lcolor(dknavy) yaxis(2) 
ytitle("Share by Quarter (Points)", axis(1))
ytitle("Difference in Cumulative Share (Line)", axis(2))
xtitle("Years Since Date of Release") 
subtitle("Return to Prison from Release Date", size(large))
yscale(range(0 .06) axis(1))
ylabel(0(.02).06, axis(1))
yscale(range(0 .17) axis(2))
ylabel(0(.05).15, axis(2))
  legend(pos(2) ring(0) cols(1) region(fcolor(gs15) lstyle(none)) size(small))
   graphregion(fcolor(white)) saving(Figures/t/fig5a, replace)  nodraw;

label var shareRecidBefAdm "FY93 Grid Cohort";
label var shareRecidAftAdm "FY94 Grid Cohort";
label var diffAdm "Difference";


*FIGURE 5B*;
scatter shareRecidBefAdm recidq, mcolor(dknavy) || 
scatter shareRecidAftAdm recidq, mcolor(emidblue) msymbol(Oh) ||
line diffAdm recidq, lpattern("-") lcolor(emidblue) yaxis(2) 
ytitle("Share by Quarter (Points)", axis(1))
ytitle("Difference in Cumulative Share (Line)", axis(2))
xtitle("Years Since Date of Admission") 
subtitle("Return to Prison from Admission Date", size(large))
xscale(titlegap(5))
yscale(range(0 .06) axis(1))
ylabel(0(.02).06, axis(1))
yscale(range(0 .17) axis(2))
ylabel(0(.05).15, axis(2))
  legend(pos(2) ring(0) cols(1) region(fcolor(gs15) lstyle(none)) size(small))
   graphregion(fcolor(white)) saving(Figures/t/fig5b, replace)  nodraw;


*FIGURE 5C*;
line diffRel recidq, lcolor(dknavy) || 
line diffAdm recidq, lpattern("-") lcolor(emidblue) yaxis(2)
xtitle("Years Since Date of Admission/Release") 
subtitle("Difference in Share Returned to Prison", size(large))
ytitle("Difference in Share Returned to Prison")
yscale(range(0 .17) axis(1))
ylabel(0(.05).15, axis(1))
ylabel(none, axis(2))
ytitle(" ", axis(1))
ytitle(" ", axis(2))
xscale(titlegap(5)) 
  legend(pos(5) ring(0) col(1) region(fcolor(gs15) lstyle(none)) size(small)
  order( 1 "Date of Release (Rehab + Aging)" 2 "Date of Admission (Incap + Rehab)"))
   graphregion(fcolor(white)) saving(Figures/t/fig5c, replace) nodraw;

gr combine Figures/t/fig5a.gph Figures/t/fig5b.gph Figures/t/fig5c.gph, title("Figure 5 - Recidivism from Release and Admission Date", size(medium)) 
xcommon cols(1) iscale(.5) xsize(8.5) ysize(10)
 graphregion(fcolor(white));
 graph export "Figures/fig5.pdf", replace;
#delimit cr;

*****************
*FIGURE A1*
*****************
 insheet using UCR/Georgia.csv, comma clear
keep if year >= 1990 & year <= 2000
gen indexrate = violentcrimerate+ propertycrimerate
keep indexrate population year
sort year 
tempfile t
save `t' 

use sampleUCR, clear
gen year = year(admitdate)
keep if year >= 1990 & year <= 2000
gen admit = 1
gen admitWithParole = dtrated != .
gen admitWithPriorAndParole = priorincars >= 1 & dtrated != .
collapse (sum) admit admitWithParole admitWithPriorAndParole, by(year)
sort year
merge 1:1 year using `t'

gen admitRate = 100000*admit/pop
gen admitWithPriorAndParoleRate = 100000*admitWithPriorAndParole/pop

#delimit;
scatter  indexrate year, mcolor(dknavy) lcolor(dknavy) c(l) || 
scatter admitRate year, c(l) mcolor(emidblue) lcolor(emidblue) lpattern("-") yaxis(2)  
legend(order(1 "UCR Index Crime Rate" 2 "Prison Admit Rate")
 pos(2) ring(0) col(1) region(fcolor(gs15) lstyle(none)))
ytitle("UCR Index Crime Rate") ytitle("Prison Admit Rate", axis(2))
ylabel(#3) ylabel(#3, axis(2)) xlabel(1990 1995 2000)
xtitle(" ")
title("Figure A1 - Crime Trends in Georgia") graphregion(fcolor(white));
graph export Figures/figA1.pdf, replace;


capture log close;
